@@ -179,7 +179,7 @@ def get_location(model_obj):
         model_obj: the model object of interest
 
     Returns:
-        the line, col and filename of the model element.
+        the line, col, nchar and filename of the model element.
         The filename may be None.
         This function may be used to fill exceptions
     """
@@ -187,7 +187,8 @@ def get_location(model_obj):
 
     the_model = get_model(model_obj)
     line, col = the_model._tx_parser.pos_to_linecol(model_obj._tx_position)
-    return {"line": line, "col": col, "filename": the_model._tx_filename}
+    nchar = model_obj._tx_position_end - model_obj._tx_position
+    return {"line": line, "col": col, "nchar": nchar, "filename": the_model._tx_filename}
 
 
 def textxerror_wrap(obj_processor):
@@ -940,9 +941,8 @@ def parse_tree_to_objgraph(
                     for m in models:
                         for _, _, delayed in m._tx_reference_resolver.delayed_crossrefs:
                             line, col = parser.pos_to_linecol(delayed.position)
-                            error_text += ' "{}" of class "{}" at {}'.format(
-                                delayed.obj_name, delayed.cls.__name__, (line, col)
-                            )
+                            error_text += f' "{delayed.obj_name}" of class ' \
+                                          f'"{delayed.cls.__name__}" at {(line, col)}'
                     raise TextXSemanticError(error_text, line=line, col=col)
 
                 for m in models:
@@ -1043,7 +1043,7 @@ def _end_model_construction(model):
             except TypeError as e:
                 # Add class name information in case of wrong
                 # constructor parameters
-                e.args += ("for class %s" % obj.__class__.__name__,)
+                e.args += (f"for class {obj.__class__.__name__}",)
                 the_parser.dprint(traceback.print_exc())
                 raise e
 
@@ -1166,9 +1166,8 @@ class ReferenceResolver:
                 if resolved is None:
                     line, col = self.parser.pos_to_linecol(crossref.position)
                     raise TextXSemanticError(
-                        message='Unknown object "{}" of class "{}"'.format(
-                            crossref.obj_name, crossref.cls.__name__
-                        ),
+                        message=f'Unknown object "{crossref.obj_name}" of class '
+                                f'"{crossref.cls.__name__}"',
                         line=line,
                         col=col,
                         err_type=UNKNOWN_OBJ_ERROR,
